@@ -5,12 +5,12 @@ package urpm::install;
 use strict;
 use urpm;
 use urpm::msg;
-use urpm::util qw(cat_utf8 member);
+use urpm::util;
 
 
 =head1 NAME
 
-urpm::install - Package installation transaction routines for urpmi
+urpm::install - Package installation transactin routines for urpmi
 
 =head1 SYNOPSIS
 
@@ -88,38 +88,25 @@ sub transaction_set_to_string {
 
 Standard logger for transactions
 
-See L<URPM> for parameters
-
 =cut
 
 # install logger callback
-my ($erase_logger, $index, $total_pkg, $uninst_count);
 sub install_logger {
-    my ($urpm, $type, undef, $subtype, $amount, $total) = @_;
+    my ($urpm, $type, $id, $subtype, $amount, $total) = @_;
+    my $pkg = defined $id && $urpm->{depslist}[$id];
+    my $total_pkg = $urpm->{nb_install};
     local $| = 1;
 
     if ($subtype eq 'start') {
 	$urpm->{logger_progress} = 0;
 	if ($type eq 'trans') {
-	    $total_pkg = $urpm->{nb_install};
 	    $urpm->{logger_count} ||= 0;
-	    $uninst_count = 0;
 	    my $p = N("Preparing...");
 	    print $p, " " x (33 - length $p);
 	} else {
-	    my $pname;
-	    my $cnt;
-	    if ($type eq 'uninst') {
-		$total_pkg = $urpm->{trans}->NElements - $index if !$uninst_count;
-		$cnt = ++$uninst_count;
-		$pname = N("removing %s", $urpm->{trans}->Element_fullname($index));
-		$erase_logger->($urpm, undef, undef, $subtype);
-	    } else {
-		$pname = $urpm->{trans}->Element_name($index);
-		++$urpm->{logger_count} if $pname;
-		$cnt = $pname ? $urpm->{logger_count} : '-';
-	    }
-	    $index++;
+	    my $pname = $pkg ? $pkg->name : '';
+	    ++$urpm->{logger_count} if $pname;
+	    my $cnt = $pname ? $urpm->{logger_count} : '-';
 	    my $s = sprintf("%9s: %-22s", $cnt . "/" . $total_pkg, $pname);
 	    print $s;
 	    $s =~ / $/ or printf "\n%9s  %-22s", '', '';
@@ -218,8 +205,7 @@ sub _apply_delta_rpm {
 }
 
 sub _schedule_packages {
-    my ($urpm, $trans, $install, $upgrade, %options) = @_;
-    my $update = 0;
+    my ($urpm, $trans, $install, $upgrade, $update, %options) = @_;
     my (@trans_pkgs, @produced_deltas);
     foreach my $mode ($install, $upgrade) {
 	foreach (keys %$mode) {
@@ -254,7 +240,7 @@ sub _schedule_packages {
 
 sub _get_callbacks {
     my ($urpm, $db, $trans, $options, $install, $upgrade, $have_pkgs) = @_;
-    $index = 0;
+    my $index;
     my $fh;
 
     my $is_test = $options->{test}; # fix circular reference
@@ -266,6 +252,7 @@ sub _get_callbacks {
     my ($callback_open_helper, $callback_close_helper) = ($options->{callback_open_helper}, $options->{callback_close_helper});
     $options->{callback_open} = sub {
 	my ($_data, $_type, $id) = @_;
+	$index++;
 	$callback_open_helper and $callback_open_helper->(@_);
 	$fh = urpm::sys::open_safe($urpm, '<', $install->{$id} || $upgrade->{$id});
 	$fh ? fileno $fh : undef;
@@ -280,9 +267,12 @@ sub _get_callbacks {
 
     #- ensure perl does not create a circular reference below, otherwise all this won't be collected,
     #  and rpmdb won't be closed
-    my $verbose = $options->{verbose};
-    $erase_logger = sub {
-	my ($urpm, undef, undef, $subtype) = @_;
+    my ($verbose, $callback_report_uninst) = ($options->{verbose}, $options->{callback_report_uninst});
+    $options->{callback_uninst} = sub { 	    
+	my ($urpm, undef, undef, $subtype, $amount, $total) = @_;
+
+	my $total_pkg = $trans->NElements - $urpm->{nb_install};
+	local $| = 1;
 
 	if ($subtype eq 'start') {
 	    my ($name, $fullname) = ($trans->Element_name($index), $trans->Element_fullname($index));
@@ -292,14 +282,34 @@ sub _get_callbacks {
 	    if (member($name, @previous)) {
 		$urpm->{log}("removing upgraded package $fullname");
 	    } else {
+		$callback_report_uninst and $callback_report_uninst->(N("Removing package %s", $fullname));
 		$urpm->{print}(N("removing package %s", $fullname)) if $verbose >= 0;
 	    }
+	    $index++;
+
+	    $urpm->{logger_uninst_progress} = 0;
+	    ++$urpm->{logger_uninst_count} if $name;
+	    my $cnt = $name ? $urpm->{logger_uninst_count} : '-';
+	    my $s = sprintf("%9s: %-22s", $cnt . "/" . $total_pkg, $name);
+	    print $s;
+	    $s =~ / $/ or printf "\n%9s  %-22s", '', '';
+
+	} elsif ($subtype eq 'stop') {
+	    if ($urpm->{logger_uninst_progress} < $progress_size) {
+		$urpm->{print}('#' x ($progress_size - $urpm->{logger_uninst_progress}));
+		$urpm->{logger_uninst_progress} = 0;
+	    }
+	} elsif ($subtype eq 'progress') {
+	    my $new_progress = $total > 0 ? int($progress_size * $amount / $total) : $progress_size;
+	    if ($new_progress > $urpm->{logger_uninst_progress}) {
+		print '#' x ($new_progress - $urpm->{logger_uninst_progress});
+		$urpm->{logger_uninst_progress} = $new_progress;
+		$urpm->{logger_uninst_progress} == $progress_size and print "\n";
+	    }
 	}
     };
 
-    $options->{callback_uninst} ||= $options->{verbose} >= 0 ? \&install_logger : $erase_logger;
-
-    $options->{callback_error} ||= sub {
+    $options->{callback_error} = sub {
 	my ($urpm, undef, $id, $subtype) = @_;
 	my $n = $urpm->{depslist}[$id]->fullname;
 	$urpm->{error}("ERROR: '$subtype' failed for $n: ");
@@ -317,17 +327,13 @@ Install packages according to each hash (remove, install or upgrade).
 
 options: 
      test, excludepath, nodeps, noorder (unused), delta, 
-     callback_inst, callback_trans, callback_uninst,
-     callback_open_helper, callback_close_helper,
+     callback_inst, callback_trans, callback_report_uninst,
      post_clean_cache, verbose
   (more options for trans->run)
      excludedocs, nosize, noscripts, oldpackage, replacepkgs, justdb, ignorearch
 
-See L<URPM> for callback parameters
-
 =cut
 
-#- side-effects: uses a $urpm->{readmes}
 sub install {
     my ($urpm, $remove, $install, $upgrade, %options) = @_;
     $options{translate_message} = 1;
@@ -346,11 +352,11 @@ sub install {
 
     $trans->set_script_fd($options{script_fd}) if $options{script_fd};
 
-    my @errors;
+    my ($update, @errors) = 0;
 
     _schedule_packages_for_erasing($urpm, $trans, $remove);
 
-    my ($produced_deltas, @trans_pkgs) = _schedule_packages($urpm, $trans, $install, $upgrade, %options);
+    my ($produced_deltas, @trans_pkgs) = _schedule_packages($urpm, $trans, $install, $upgrade, $update, %options);
 
     if (!$options{nodeps} && (@errors = $trans->check(%options))) {
     } elsif (!$options{noorder} && (@errors = $trans->order)) {
@@ -359,10 +365,7 @@ sub install {
 
 	_get_callbacks($urpm, $db, $trans, \%options, $install, $upgrade, scalar @trans_pkgs);
 
-	local $urpm->{trans} = $trans;
 	@errors = $trans->run($urpm, %options);
-	delete $urpm->{trans};
-	undef $erase_logger;
 
 	#- don't clear cache if transaction failed. We might want to retry.
 	if (!@errors && !$options{test} && $options{post_clean_cache}) {
@@ -406,6 +409,6 @@ Copyright (C) 1999-2005 MandrakeSoft SA
 
 Copyright (C) 2005-2010 Mandriva SA
 
-Copyright (C) 2011-2013 Mageia
+Copyright (C) 2011-2012 Mageia
 
 =cut
